@@ -1,4 +1,4 @@
-package Pcore::Nginx v1.2.3;
+package Pcore::Nginx v1.3.0;
 
 use Pcore -dist, -class, -try;
 
@@ -34,6 +34,16 @@ sub _build_vhost_dir ($self) {
 }
 
 sub run ($self) {
+
+    # generate mime types
+    my $mime_types = P->cfg->load( $ENV->share->get('data/mime.json') )->{suffix};
+
+    my $nginx_mime_types;
+
+    for my $suffix ( keys $mime_types->%* ) {
+        $nginx_mime_types->{ lc $suffix } = ref $mime_types->{ lc $suffix } eq 'ARRAY' ? $mime_types->{ lc $suffix }->[0] : $mime_types->{ lc $suffix };
+    }
+
     my $params = {
         user               => $self->user,
         pid                => $self->conf_dir . 'nginx.pid',
@@ -43,22 +53,12 @@ sub run ($self) {
         geoip_city_path    => $ENV->share->get('/data/geoip_city.dat') // undef,
         vhost_dir          => $self->vhost_dir,
         ssl_dhparam        => $ENV->share->get('/data/nginx/dhparam-4096.pem'),
+        mime_types         => $nginx_mime_types,
     };
 
-    my $mime_types = P->cfg->load( $ENV->share->get('data/mime.json') )->{suffix};
-
-    my $nginx_mime_types;
-
-    for my $suffix ( keys $mime_types->%* ) {
-        $nginx_mime_types->{ lc $suffix } = ref $mime_types->{ lc $suffix } eq 'ARRAY' ? $mime_types->{ lc $suffix }->[0] : $mime_types->{ lc $suffix };
-    }
-
-    P->file->write_text( $self->conf_dir . 'mime.types', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/mime.types', { mime_types => $nginx_mime_types } ) );
-
+    # generate conf.nginx
     P->file->write_text( $self->conf_dir . 'conf.nginx', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/conf.nginx', $params ) );
 
-    P->file->write_text( $self->conf_dir . 'ssl.nginx', { mode => q[rw-r--r--] }, P->tmpl( type => 'text' )->render( 'nginx/ssl.nginx', $params ) );
-
     P->pm->run_proc(
         [ $self->nginx_bin, '-c', $self->conf_dir . 'conf.nginx' ],
         on_ready => sub ($proc) {
